==> mall-center-api-0.1.13.6-20211118.054730-7-sources.jar: cn/com/duiba/mall/center/api/domain/dto/discount/DiscountWhitelistDto.java <==
package cn.com.duiba.mall.center.api.domain.dto.discount;

import java.util.Date;

/**
* 优惠券白名单明细表
*/
public class DiscountWhitelistDto {

    /**
    * 主键
    */
    private Long id;

    /**
    * appid
    */
    private Long appId;

    /**
    * tb_discount_whitelist_batch表id
    */
    private Long bacthId;

    private Long discountId;

    /**
    * 1：开发者uid
    */
    private Integer relType;

    /**
    * 白名单值
    */
    private String relValue;

    /**
    * 0：未删除、1：删除
    */
    private Integer deleted;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;

    /**
    * 扩展
    */
    private String extraJson;


    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setBacthId(Long bacthId) {
        this.bacthId = bacthId;
    }

    public Long getBacthId() {
        return bacthId;
    }

    public void setRelType(Integer relType) {
        this.relType = relType;
    }

    public Integer getRelType() {
        return relType;
    }

    public void setRelValue(String relValue) {
        this.relValue = relValue;
    }

    public String getRelValue() {
        return relValue;
    }

    public void setDeleted(Integer deleted) {
        this.deleted = deleted;
    }

    public Integer getDeleted() {
        return deleted;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setExtraJson(String extraJson) {
        this.extraJson = extraJson;
    }

    public String getExtraJson() {
        return extraJson;
    }

    public Long getDiscountId() {
        return discountId;
    }

    public void setDiscountId(Long discountId) {
        this.discountId = discountId;
    }
}

==> mall-center-api-0.1.33-sources.jar: cn/com/duiba/mall/center/api/domain/dto/discount/DiscountWhitelistDto.java <==
package cn.com.duiba.mall.center.api.domain.dto.discount;

import java.io.Serializable;
import java.util.Date;

/**
* 优惠券白名单明细表
*/
public class DiscountWhitelistDto implements Serializable {

    /**
    * 主键
    */
    private Long id;

    /**
    * appid
    */
    private Long appId;

    /**
    * tb_discount_whitelist_batch表id
    */
    private Long bacthId;

    private Long discountId;

    /**
    * 1：开发者uid
    */
    private Integer relType;

    /**
    * 白名单值
    */
    private String relValue;

    /**
    * 0：未删除、1：删除
    */
    private Integer deleted;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;

    /**
    * 扩展
    */
    private String extraJson;


    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setBacthId(Long bacthId) {
        this.bacthId = bacthId;
    }

    public Long getBacthId() {
        return bacthId;
    }

    public void setRelType(Integer relType) {
        this.relType = relType;
    }

    public Integer getRelType() {
        return relType;
    }

    public void setRelValue(String relValue) {
        this.relValue = relValue;
    }

    public String getRelValue() {
        return relValue;
    }

    public void setDeleted(Integer deleted) {
        this.deleted = deleted;
    }

    public Integer getDeleted() {
        return deleted;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setExtraJson(String extraJson) {
        this.extraJson = extraJson;
    }

    public String getExtraJson() {
        return extraJson;
    }

    public Long getDiscountId() {
        return discountId;
    }

    public void setDiscountId(Long discountId) {
        this.discountId = discountId;
    }
}
